@@ -6,16 +6,10 @@
  *
  * Licensed under the MIT license.
  */
-
-#include <unistd.h>
 #include <stdio.h>
 #include <string.h>
-#include <stdint.h>
-#include <stdlib.h>
-#include <glib/gi18n.h>
-#define __USE_XOPEN
-#include <time.h>
-#include <math.h>
+
+#include "gettext.h"
 
 #include "dive.h"
 #include "uemis.h"
@@ -166,8 +160,10 @@ void uemis_mark_divelocation(int diveid, int divespot, char **location, degrees_
 void uemis_set_divelocation(int divespot, char *text, double longitude, double latitude)
 {
 	struct uemis_helper *hp = uemis_helper;
+#if 0	/* seems overkill */
 	if (!g_utf8_validate(text, -1, NULL))
 		return;
+#endif
 	while (hp) {
 		if (hp->divespot == divespot && hp->location) {
 			*hp->location = strdup(text);
@@ -195,45 +191,45 @@ static void uemis_event(struct dive *dive, struct divecomputer *dc, struct sampl
 	static int lastndl;
 
 	if (flags[1] & 0x01)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Safety Stop Violation"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Safety Stop Violation"));
 	if (flags[1] & 0x08)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Speed Alarm"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Speed Alarm"));
 #if WANT_CRAZY_WARNINGS
 	if (flags[1] & 0x06) /* both bits 1 and 2 are a warning */
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Speed Warning"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Speed Warning"));
 	if (flags[1] & 0x10)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("PO2 Green Warning"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","PO2 Green Warning"));
 #endif
 	if (flags[1] & 0x20)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("PO2 Ascend Warning"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","PO2 Ascend Warning"));
 	if (flags[1] & 0x40)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("PO2 Ascend Alarm"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","PO2 Ascend Alarm"));
 	/* flags[2] reflects the deco / time bar
 	 * flags[3] reflects more display details on deco and pO2 */
 	if (flags[4] & 0x01)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Tank Pressure Info"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Tank Pressure Info"));
 	if (flags[4] & 0x04)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("RGT Warning"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","RGT Warning"));
 	if (flags[4] & 0x08)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("RGT Alert"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","RGT Alert"));
 	if (flags[4] & 0x40)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Tank Change Suggested"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Tank Change Suggested"));
 	if (flags[4] & 0x80)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Depth Limit Exceeded"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Depth Limit Exceeded"));
 	if (flags[5] & 0x01)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Max Deco Time Warning"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Max Deco Time Warning"));
 	if (flags[5] & 0x04)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Dive Time Info"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Dive Time Info"));
 	if (flags[5] & 0x08)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Dive Time Alert"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Dive Time Alert"));
 	if (flags[5] & 0x10)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Marker"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Marker"));
 	if (flags[6] & 0x02)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("No Tank Data"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","No Tank Data"));
 	if (flags[6] & 0x04)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Low Battery Warning"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Low Battery Warning"));
 	if (flags[6] & 0x08)
-		add_event(dc, sample->time.seconds, 0, 0, 0, N_("Low Battery Alert"));
+		add_event(dc, sample->time.seconds, 0, 0, 0, QT_TRANSLATE_NOOP("gettextFromC","Low Battery Alert"));
 	/* flags[7] reflects the little on screen icons that remind of previous
 	 * warnings / alerts - not useful for events */
 
@@ -297,7 +293,7 @@ void uemis_parse_divelog_binary(char *base64, void *datap) {
 
 	datalen = uemis_convert_base64(base64, &data);
 
-	dive->dc.airtemp.mkelvin = *(uint16_t *)(data + 45) * 100 + ZERO_C_IN_MKELVIN;
+	dive->dc.airtemp.mkelvin = C_to_mkelvin(*(uint16_t *)(data + 45));
 	dive->dc.surface_pressure.mbar = *(uint16_t *)(data + 43);
 	if (*(uint8_t *)(data + 19))
 		dive->dc.salinity = SEAWATER_SALINITY; /* avg grams per 10l sea water */
@@ -355,7 +351,7 @@ void uemis_parse_divelog_binary(char *base64, void *datap) {
 		sample = prepare_sample(dc);
 		sample->time.seconds = u_sample->dive_time;
 		sample->depth.mm = rel_mbar_to_depth(u_sample->water_pressure, dive);
-		sample->temperature.mkelvin = (u_sample->dive_temperature * 100) + ZERO_C_IN_MKELVIN;
+		sample->temperature.mkelvin = C_to_mkelvin(u_sample->dive_temperature);
 		sample->sensor = active;
 		sample->cylinderpressure.mbar =
 			(u_sample->tank_pressure_high * 256 + u_sample->tank_pressure_low) * 10;
